import { ref } from 'vue';

// 弹窗配置
export const formConfig = ref({
  system: {
    forms: [
      {
        label: '名称',
        name: 'name',
        type: 'input',
        span: 24,
        rules: [
          {
            required: true,
            message: '请输入名称!',
            trigger: 'blur'
          },
          { min: 3, max: 10, message: '长度应该在3-10之间', trigger: 'blur' }
        ],
        attrs: { placeholder: '请输入名称', clearable: true }
      },
      {
        label: '编码',
        name: 'code',
        type: 'input',
        rules: [
          {
            required: true,
            message: '请输入编码!',
            trigger: 'blur'
          },
          { min: 1, max: 20, message: '长度应该在1-20之间', trigger: 'blur' }
        ],
        span: 24,
        attrs: { placeholder: '请输入编码', clearable: true }
      },
      {
        label: '描述',
        name: 'desc',
        type: 'input',
        span: 24,
        rules: [
          {
            required: true,
            message: '请输入描述!',
            trigger: 'blur'
          },
          { min: 1, max: 256, message: '长度应该在1-256之间', trigger: 'blur' }
        ],
        attrs: {
          type: 'textarea',
          maxlength: 256,
          clearable: true,
          placeholder: '请输入描述信息，最多可输入256字',
          minRows: 5,
          maxRows: 8,
          rows: 6,
          style: {
            width: '100%'
          }
        }
      }
    ],
    formValues: {
      name: '',
      desc: '',
      code: ''
    },
    copyForms: [
      {
        label: '名称',
        name: 'name',
        type: 'input',
        span: 24,
        rules: [
          {
            required: true,
            message: '请输入名称!',
            trigger: 'blur'
          },
          { min: 3, max: 10, message: '长度应该在3-10之间', trigger: 'blur' }
        ],
        attrs: { placeholder: '请输入名称', clearable: true }
      },
      {
        label: '根路径',
        name: 'code',
        type: 'input',
        span: 24,
        rules: [
          {
            required: true,
            message: '请输入编码!',
            trigger: 'blur'
          },
          { min: 1, max: 20, message: '长度应该在1-20之间', trigger: 'blur' }
        ],
        attrs: { placeholder: '请输入名称', clearable: true }
      }
    ],
    copyValues: {
      name: '',
      code: ''
    },
    versionForms: [
      {
        name: 'stateValue',
        type: 'select',
        label: '版本切换',
        span: 24,
        attrs: {
          style: {
            width: '276px'
          },
          options: [],
          propsMap: {
            label: 'version',
            value: 'id'
          },
          clearable: true,
          placeholder: '请选择版本！'
        }
      }
    ],
    versionValues: {
      stateValue: ''
    }
  },
  module: {
    forms: [
      {
        name: 'name',
        type: 'input',
        label: '名称',
        span: 24,
        rules: [
          {
            required: true,
            message: '请输入名称!',
            trigger: 'blur'
          },
          { min: 3, max: 10, message: '长度应该在3-10之间', trigger: 'blur' }
        ],
        attrs: {
          style: {
            width: '276px'
          },
          clearable: true,
          placeholder: '请输入名称'
        }
      },
      {
        name: 'code',
        type: 'input',
        label: '编码',
        span: 24,
        rules: [
          {
            required: true,
            message: '请输入编码!',
            trigger: 'blur'
          },
          { min: 1, max: 20, message: '长度应该在1-20之间', trigger: 'blur' }
        ],
        attrs: {
          style: {
            width: '276px'
          },
          clearable: true,
          placeholder: '请输入编码'
        }
      },
      {
        name: 'desc',
        type: 'input',
        label: '描述',
        rules: [
          {
            required: true,
            message: '请输入描述!',
            trigger: 'blur'
          },
          { min: 1, max: 256, message: '长度应该在1-256之间', trigger: 'blur' }
        ],
        span: 24,
        attrs: {
          type: 'textarea',
          maxlength: 300,
          clearable: true,
          placeholder: '请输入描述信息，最多可输入300字',
          minRows: 5,
          maxRows: 8,
          rows: 6,
          style: {
            width: '100%'
          }
        }
      }
    ]
  },
  logic: {
    forms: [
      {
        name: 'name',
        type: 'input',
        label: '名称',
        span: 24,
        rules: [
          {
            required: true,
            message: '请输入名称!',
            trigger: 'blur'
          },
          { min: 3, max: 10, message: '长度应该在3-10之间', trigger: 'blur' }
        ],
        attrs: {
          style: {
            width: '276px'
          },
          clearable: true,
          placeholder: '请输入名称'
        }
      },
      {
        name: 'requestUrl',
        type: 'input',
        label: 'URL',
        span: 24,
        rules: [
          {
            required: true,
            message: '请输入URL!',
            trigger: 'blur'
          },
          { min: 1, max: 256, message: '长度应该在1-256之间', trigger: 'blur' }
        ],
        attrs: {
          style: {
            width: '276px'
          },
          clearable: true,
          placeholder: '请输入URL'
        }
      },
      {
        name: 'requestType',
        type: 'select',
        label: '请求方法',
        span: 24,
        attrs: {
          style: {
            width: '276px'
          },
          options: [
            { label: 'GET', value: 'GET' },
            { label: 'POST', value: 'POST' },
            { label: 'PUT', value: 'PUT' },
            { label: 'DELETE', value: 'DELETE' },
            { label: 'PATCH', value: 'PATCH' },
            { label: 'WS', value: 'WS' }
          ],
          clearable: true,
          placeholder: '请输入URL'
        }
      },
      {
        name: 'desc',
        type: 'input',
        label: '描述',
        span: 24,
        rules: [
          {
            required: true,
            message: '请输入描述!',
            trigger: 'blur'
          },
          { min: 1, max: 256, message: '长度应该在1-256之间', trigger: 'blur' }
        ],
        attrs: {
          type: 'textarea',
          maxlength: 300,
          clearable: true,
          placeholder: '请输入描述信息，最多可输入300字',
          minRows: 5,
          maxRows: 8,
          rows: 6,
          style: {
            width: '100%'
          }
        }
      }
    ]
  }
});

// 搜索项配置
export const searchConfig = ref({
  system: {
    params: [
      {
        label: '应用名称',
        name: 'name',
        type: 'input',
        span: 6,
        attrs: { placeholder: '请输入应用名称', clearable: true }
      },
      {
        label: '应用状态',
        name: 'type',
        type: 'select',
        span: 6,
        attrs: {
          placeholder: '请选择应用状态',
          clearable: true,
          options: [
            { label: '在线', name: 'online' },
            { label: '离线', name: 'offline' }
          ]
        }
      }
    ],
    formValues: {
      name: '',
      type: ''
    }
  }
});

// 表格配置
export const tableConfig = ref({
  system: {
    header: [
      { name: 'name', label: '应用中文名', width: '160' },
      { name: 'code', label: '应用英文名', width: '160' },
      { name: 'executeServiceUrl', label: '访问链接', width: '220' },
      { name: 'logicServiceNumber', label: '接口数量', width: '' },
      { name: 'subTitle', label: '修改时间', width: '180' },
      { name: 'createTime', label: '创建时间', width: '180' },
      { name: 'desc', label: '描述', width: '280' },
      {
        name: 'custom',
        type: 'custom',
        fixed: 'right',
        label: '操作',
        width: '240'
      }
    ]
  }
});
